import {
  select,
  scaleOrdinal,
  schemeSpectral,
  timer,
} from 'd3';
import { loadAndProcessData } from './loadAndProcessData';
import { colorLegend } from './colorLegend';
import { choroplethMap } from './choroplethMap';

const svg = select('svg');
const choroplethMapG = svg.append('g');
const colorLegendG = svg
  .append('g')
  .attr('transform', `translate(740,300)`);

const colorScale = scaleOrdinal();

// const colorValue = d => d.properties.income_grp;
const colorValue = (d) => d.properties.economy;

let selectedColorValue;
let features;

const onClick = (d) => {
  selectedColorValue = d;
  render();
};

loadAndProcessData().then((countries) => {
  features = countries.features;
  render();
});
const para = 'Hover and Zoom';

const render = () => {
  svg
    .attr('class', 'globe-text-1')
    .append('text')
    .attr('x', 730)
    .attr('y', 60)
    .attr('font-size', '30px')
    .text('Interactive Globe');
  svg

    .attr('class', 'globe-text-2')
    .append('text')
    .attr('x', 730)
    .attr('font-size', '24px')
    .attr('y', 90)
    .text(para);
  svg

    .attr('class', 'globe-text-2')
    .append('text')
    .attr('x', 730)
    .attr('y', 120)
    .text('Click on the Globe');
  colorScale
    .domain(features.map(colorValue))
    .domain(colorScale.domain().sort().reverse())
    .range(
      schemeSpectral[colorScale.domain().length]
    );

  colorLegendG.call(colorLegend, {
    colorScale,
    circleRadius: 8,
    spacing: 20,
    textOffset: 12,
    backgroundRectWidth: 235,
    onClick,
    selectedColorValue,
  });

  choroplethMapG.call(choroplethMap, {
    features,
    colorScale,
    colorValue,
    selectedColorValue,
  });
};
